@@ -1,5 +1,5 @@
 `findSupersets` <-
-function (noflevels, input.combs) {
+function (noflevels3k, input.combs) {
     if (!is.matrix(input.combs)) {
         if (!is.vector(input.combs)) {
             cat("\n")
@@ -7,16 +7,16 @@ function (noflevels, input.combs) {
                  call. = FALSE)
         }
         else {
-            if (any(input.combs > prod(noflevels))) {
+            if (any(input.combs > prod(noflevels3k))) {
                 cat("\n")
                 stop(paste("Some line numbers do not belong in the solution-space for",
-                           length(noflevels), "causal conditions.\n\n"), call. = FALSE)
+                           length(noflevels3k), "causal conditions.\n\n"), call. = FALSE)
             }
-            input.combs <- getRow(noflevels, input.combs)
+            input.combs <- getRow(noflevels3k, input.combs)
         }
     }
-    mbase <- rev(c(1, cumprod(rev(noflevels))))[-1]
-    allcombn <- t(createMatrix(rep(2, length(noflevels)))[-1, ])
+    mbase <- rev(c(1, cumprod(rev(noflevels3k))))[-1]
+    allcombn <- t(createMatrix(rep(2, length(noflevels3k)))[-1, ])
     primes <- sort(unique(as.vector(apply(input.combs, 1, function(x) (x*mbase) %*% allcombn + 1))))
     if (primes[1] == 1) {
         return(primes[-1])
